// fragment shader
precision mediump float;
varying vec2 textureCoordinate;

varying vec4 varyingPotion;
uniform float bound;
uniform vec3 param1;
uniform vec3 param2;


uniform sampler2D inputImageTexture;
float saturation;
const mediump vec3 luminanceWeighting = vec3(0.2125, 0.7154, 0.0721);

vec3 rgbToHsl(float r, float g, float b) {
    float min = min(r, min(g, b));
    float max = max(r, max(g, b));
    float h, s, l = (max + min) / 2.0;
    if(max == min){
        h = s = 0.0;
    }  else  {
        float d = max - min;
        s = l > 0.5 ? d / (2.0 - max - min) : d / (max + min);
        if (max == r) h = (g - b) / d + (g < b ? 6.0 : 0.0);
        if (max == g) h = (b - r) / d + 2.0;
        if (max == b) h = (r - g) / d + 4.0;
        h /= 6.0;
    }
    return vec3(h, s, l);
}

float draw(vec3 hslColor,vec3 param){
    if(param.z == 0.0){
       // 不过滤颜色
       saturation = 1.0;
    } else if(param.z == 1.0){
       // 过滤红色
       if(hslColor.x <= param.y || hslColor.x >= param.x){
           saturation = 1.0;
       }
       else {
           saturation = 0.0;
       }
    } else {
       // 过滤其他颜色
       if(hslColor.x <= param.y && hslColor.x >= param.x){
           saturation = 1.0;
       }
       else {
           saturation = 0.0;
       }
    }
    return saturation;
}

void main() {
    lowp vec4 textureColor = texture2D(inputImageTexture, textureCoordinate);
    lowp float luminance = dot(textureColor.rgb, luminanceWeighting);
    lowp vec3 greyScaleColor = vec3(luminance);
    lowp vec3 hslColor = rgbToHsl(textureColor.r, textureColor.g, textureColor.b);
    if(varyingPotion.x > bound){
        saturation = draw(hslColor,param1);
    }else {
        saturation = draw(hslColor,param2);
    }

    gl_FragColor = vec4(mix(greyScaleColor, textureColor.rgb, saturation), textureColor.w);
}